#[non_exhaustive]pub enum AtomTextType {
Text,
Html,
}Expand description
Text content for <title>, <summary>, <content> per RFC 4287 3.1.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Text
Plain text. Special characters are XML-escaped.
Html
HTML payload. Treated as opaque text by this module and emitted verbatim after XML-escaping; consumers are responsible for ensuring the payload is safe.