RssDataField

Enum RssDataField 

pub enum RssDataField {
Show 19 variants AtomLink, Author, Category, Copyright, Description, Docs, Generator, Guid, ImageTitle, ImageUrl, ImageLink, Language, LastBuildDate, Link, ManagingEditor, PubDate, Title, Ttl, Webmaster,
}
Represents the fields of an RSS data structure.

Variants

The Atom link of the RSS feed.



Author

The author of the RSS feed.



Category

The category of the RSS feed.



Copyright

The copyright notice.



Description

The description of the RSS feed.



Docs

The docs link of the RSS feed.



Generator

The generator of the RSS feed.



Guid

The GUID of the RSS feed.



ImageTitle

The image title of the RSS feed.



ImageUrl

The image URL of the RSS feed.

The image link of the RSS feed.



Language

The language of the RSS feed.



LastBuildDate

The last build date of the RSS feed.

The main link to the RSS feed.



ManagingEditor

The managing editor of the RSS feed.



PubDate

The publication date of the RSS feed.



Title

The title of the RSS feed.



Ttl

Time To Live (TTL), the number of minutes the feed should be cached before refreshing.



Webmaster

The webmaster of the RSS feed.